summaryrefslogtreecommitdiff
path: root/cpu/arm920t/speed.c
diff options
context:
space:
mode:
Diffstat (limited to 'cpu/arm920t/speed.c')
-rw-r--r--cpu/arm920t/speed.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/cpu/arm920t/speed.c b/cpu/arm920t/speed.c
index 1ee0c1a15a..4942727272 100644
--- a/cpu/arm920t/speed.c
+++ b/cpu/arm920t/speed.c
@@ -42,7 +42,7 @@
/* ------------------------------------------------------------------------- */
/* NOTE: This describes the proper use of this file.
*
* CONFIG_PLL_INPUT_FREQ should be defined as the input frequency of the PLL.
*
* get_FCLK(), get_HCLK(), get_PCLK() and get_UCLK() return the clock of
* the specified bus in HZ.
@@ -64,7 +64,7 @@ static ulong get_PLLCLK(int pllreg)
p = ((r & 0x003F0) >> 4) + 2;
s = r & 0x3;
- return((CONFIG_PLL_INPUT_FREQ * m) / (p << s));
+ return((CONFIG_SYS_CLK_FREQ * m) / (p << s));
}
/* return FCLK frequency */
@@ -42,7 +42,7 @@
/* NOTE: This describes the proper use of this file.
*
- * CONFIG_PLL_INPUT_FREQ should be defined as the input frequency of the PLL.
+ * CONFIG_SYS_CLK_FREQ should be defined as the input frequency of the PLL.
*
* get_FCLK(), get_HCLK(), get_PCLK() and get_UCLK() return the clock of